@@ -26,6 +26,7 @@ import android.media.MediaPlayer.OnErrorListener;
 import android.media.MediaPlayer.OnPreparedListener;
 import android.media.MediaRecorder;
 import android.os.Environment;
+import android.os.Build;
 
 import org.apache.cordova.LOG;
 
@@ -94,6 +95,7 @@ public class AudioPlayer implements OnCompletionListener, OnPreparedListener, On
     private MediaPlayer player = null;      // Audio player object
     private boolean prepareOnly = true;     // playback after file prepare flag
     private int seekOnPrepared = 0;     // seek to this location once media is prepared
+    private float setRateOnPrepared = -1;
 
     /**
      * Constructor.
@@ -492,6 +494,9 @@ public class AudioPlayer implements OnCompletionListener, OnPreparedListener, On
         this.player.setOnCompletionListener(this);
         // seek to any location received while not prepared
         this.seekToPlaying(this.seekOnPrepared);
+        // apply any playback rate received while not prepared
+        if (setRateOnPrepared >= 0)
+            this.player.setPlaybackParams (this.player.getPlaybackParams().setSpeed(setRateOnPrepared));
         // If start playing after prepared
         if (!this.prepareOnly) {
             this.player.start();
@@ -706,7 +711,7 @@ public class AudioPlayer implements OnCompletionListener, OnPreparedListener, On
                     fileInputStream.close();
                 }
                 else {
-                    this.player.setDataSource(Environment.getExternalStorageDirectory().getPath() + "/" + file);
+                    this.player.setDataSource(createAudioFilePath(file));
                 }
             }
                 this.setState(STATE.MEDIA_STARTING);
@@ -765,4 +770,32 @@ public class AudioPlayer implements OnCompletionListener, OnPreparedListener, On
         }
         return 0;
     }
+
+    /**
+     * Set the playback rate for the player (ignored on API < 23)
+     *
+     * @param volume
+     */
+    public void setRate(float rate) {
+        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.M) {
+            LOG.d(LOG_TAG, "AudioPlayer Warning: Request to set playback rate not supported on current OS version");
+            return;
+        }
+
+        if (this.player != null) {
+            try {
+                boolean wasPlaying = this.player.isPlaying();
+
+                this.player.setPlaybackParams(this.player.getPlaybackParams().setSpeed(rate));
+
+                if (!wasPlaying && this.player.isPlaying()) {
+                    this.player.pause();
+                }
+            } catch(Exception e) {
+                e.printStackTrace();
+            }
+        } else {
+            setRateOnPrepared = rate;
+        }
+    }
 }
